.. image:: https://travis-ci.org/WorldWideTelescope/pywwt.svg?branch=tests
    :target: https://travis-ci.org/WorldWideTelescope/pywwt

.. image:: https://ci.appveyor.com/api/projects/status/yweuddwyxy97d8go/branch/master?svg=true
    :target: https://ci.appveyor.com/project/astrofrog/pywwt/branch/master

.. image:: https://readthedocs.org/projects/pywwt/badge/?version=latest
   :target: http://pywwt.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

WorldWide Telescope from Python/Jupyter
=======================================

About
-----

The pywwt package aims to make it easy to use WorldWide Telescope from Python,
and includes the following:

* A Jupyter notebook/lab widget
* A standalone Qt viewer/widget
* A client for the Windows version of WorldWide Telescope

The documentation, including installation instructions, can be found at
http://pywwt.readthedocs.io

Reporting issues
----------------

If you run into any issues, please open an issue `here
<https://github.com/WorldWideTelescope/pywwt/issues>`_

Acknowledgments
---------------

This work is funded through the American Astronomical Society WorldWide Telescope
project.
